## Welcome to meca3's wiki ! :smile:

meca3 is a module designed to perform _point's mechanics_ in 3D. It makes you save time when dealing with _linear algebra_, _geometry_ and _differential equations_.

### Main features

meca3 is a mechanics framework. It **represents 3D** euclidean space and allows :

- Perform 3D **affine space operations** 
- Perform 3D **geometrical transformations**
- Perform 3x3 matrix **algebraical operations**
- Solve **second order ODE**
- **Manipulate trajectory** of mobile 
- **Generate trajectory** from ODE solver


### Install

Install with the following command
```
npm install meca3
```

Use the provided modules with require
```js
const Vector3 = require("meca3").Vector3;
```

**Browser**: the module is compatible with browser. Install the module and import each file as follows
```html
<script src="path/to/meca3/Vector3.js"></script>
```
You can then use the modules in your browser js files.

### Run unit tests
Unit testing is performed using **mocha** and **chai** frameworks. 
Install the framework and go to the test directory. Run the following command

```
npm test
``` 

### Structure of package

The package has an object oriented structure that is detailed in this [UML class diagram](https://www.lucidchart.com/documents/view/fc7489c5-a25e-426f-a0d8-7b27be15a3a5)

**Notes** 
- This diagram represents **only the main features** of the package.
- Red relationships means that a strong reference is used.
- Properties suffixed by `()` are Javascript **method property**
- The classes in grey have not been yet implemented

### Documentation

Each class of the module is documented here. The main features only are documented. 

Take a look at the [getting started](https://github.com/samiBendou/meca3/wiki/Getting-Started/) page if you want a brief introduce to the module features.

When it's said that features are _extended_ from another class that means that theses features behaves the same as in the initial class (eg. method inheritance). Thus theses are not  necessarily documented.

### Motivations

I found that there is a lot of physics engine written in Javascript but theses ones does not fit real word physics.

I decided to find a way to do realistic physics in Javascript in a **performant** and **time saving** way

So I write this module for 3D geometry and mechanics so I can do **point's mechanics** with an arbitrarily realistic physics.

