<a name="Matrix3"></a>

## Matrix3
**Kind**: global class  
**Brief**: 3x3 matrices  
**Details**: `Matrix3` class represents dense 3x3 matrices.

Components are stored in memory as an aggregation of three Vector3 rows : `x`, `y`, `z`.

Access a component of the matrix with the syntax `m.i.j` where `i` and `j` might be equal to `x`, `y` or `z`.
eg. `m.x.x`, `m.y.z`, ...

Construct a matrix by explicitly giving components.
eg. ` new Matrix3(1, 2, 3)` fills the first row `x` with `{x = 1, y = 2, z = 3}`.

#### Features

- Use extended **vector space operations** and **geometrical operations** from `Vector3`.

- Compute  **algebraical operations** such as inversion, product or determinant.

- Create matrices using **generators** in a Matlab-style syntax such as `eye`, `ones`, ...

- All the generators from `Vector3` are extended to `Matrix3` class.  
**Author**: samiBendou  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| x | <code>Vector3</code> | first row |
| y | <code>Vector3</code> | second row |
| z | <code>Vector3</code> | third row |


* [Matrix3](#Matrix3)
    * _instance_
        * [.trans](#Matrix3+trans) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.det](#Matrix3+det) ⇒ <code>number</code>
        * [.inv](#Matrix3+inv) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.row(i)](#Matrix3+row) ⇒ <code>Vector3</code>
        * [.col(j)](#Matrix3+col) ⇒ <code>Vector3</code>
        * [.prod(m)](#Matrix3+prod) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.map(u)](#Matrix3+map) ⇒ <code>Vector3</code>
        * [.toArray()](#Matrix3+toArray) ⇒ <code>Array</code>
    * _static_
        * [.eye](#Matrix3.eye) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.scal(s)](#Matrix3.scal) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.e(i, j)](#Matrix3.e) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.prod(matrices)](#Matrix3.prod) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.rotX(theta)](#Matrix3.rotX) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.rotY(theta)](#Matrix3.rotY) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.rotZ(theta)](#Matrix3.rotZ) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.makeRot()](#Matrix3.makeRot) ⇒ <code>function</code>
        * [.makeAffine(m, v)](#Matrix3.makeAffine) ⇒ <code>function</code>
        * [.tens(u, v)](#Matrix3.tens) ⇒ [<code>Matrix3</code>](#Matrix3)
        * [.fromArray(arr)](#Matrix3.fromArray) ⇒ [<code>Matrix3</code>](#Matrix3)

<a name="Matrix3+trans"></a>

### matrix3.trans ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: instance property of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of the transposed matrix  
**Brief**: transpose the matrix  
<a name="Matrix3+det"></a>

### matrix3.det ⇒ <code>number</code>
**Kind**: instance property of [<code>Matrix3</code>](#Matrix3)  
**Returns**: <code>number</code> - value of the determinant  
**Brief**: determinant of a matrix  
<a name="Matrix3+inv"></a>

### matrix3.inv ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: instance property of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of the inverse matrix  
**Brief**: inverse of a matrix  
**Details**: returns a `NaN` matrix when the determinant is zero.  
<a name="Matrix3+row"></a>

### matrix3.row(i) ⇒ <code>Vector3</code>
**Kind**: instance method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: <code>Vector3</code> - value of the row  
**Brief**: i-th row  

| Param | Type | Description |
| --- | --- | --- |
| i | <code>number</code> | index of the row to get |

<a name="Matrix3+col"></a>

### matrix3.col(j) ⇒ <code>Vector3</code>
**Kind**: instance method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: <code>Vector3</code> - value of the column  
**Brief**: j-th column  

| Param | Type | Description |
| --- | --- | --- |
| j | <code>number</code> | index of the column to get |

<a name="Matrix3+prod"></a>

### matrix3.prod(m) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: instance method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of the product  
**Brief**: product between two matrix  

| Param | Type | Description |
| --- | --- | --- |
| m | [<code>Matrix3</code>](#Matrix3) | matrix to multiply |

<a name="Matrix3+map"></a>

### matrix3.map(u) ⇒ <code>Vector3</code>
**Kind**: instance method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: <code>Vector3</code> - value of linear mapping  
**Brief**: product between matrix and vector  
**Details**: Also called linear mapping between matrix and vector.  

| Param | Type | Description |
| --- | --- | --- |
| u | <code>Vector3</code> | vector to multiply |

<a name="Matrix3+toArray"></a>

### matrix3.toArray() ⇒ <code>Array</code>
**Kind**: instance method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: <code>Array</code> - bi-dimensional array containing rows of the matrix  
**Brief**: transform matrix to array  
<a name="Matrix3.eye"></a>

### Matrix3.eye ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static property of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of identity matrix  
**Brief**: identity matrix  
**Details**: Diagonal matrix filled with `1`.  
<a name="Matrix3.scal"></a>

### Matrix3.scal(s) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of scalar matrix  
**Brief**: scalar matrix  
**Details**: Diagonal matrix filled with a single value.  

| Param | Type | Description |
| --- | --- | --- |
| s | <code>number</code> | scalar value |

<a name="Matrix3.e"></a>

### Matrix3.e(i, j) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of canonical matrix  
**Brief**: canonical matrix  
**Details**: Matrix with `0` everywhere except in `i`, `j` position where there is a `1`.  

| Param | Type | Description |
| --- | --- | --- |
| i | <code>number</code> | row index of `1` |
| j | <code>number</code> | column index of `1` |

<a name="Matrix3.prod"></a>

### Matrix3.prod(matrices) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of the product  
**Details**: product of the matrices in array  
**Details**: The product is performed in the same order as the elements in the array.  

| Param | Type | Description |
| --- | --- | --- |
| matrices | <code>Array</code> | array of `Vector3` |

<a name="Matrix3.rotX"></a>

### Matrix3.rotX(theta) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of rotation matrix for specified angle  
**Brief**: rotation matrix of axis (`0`, `ex`)  
**Details**: Anticlockwise rotation.  

| Param | Type | Description |
| --- | --- | --- |
| theta | <code>number</code> | angle of rotation |

<a name="Matrix3.rotY"></a>

### Matrix3.rotY(theta) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of rotation matrix for specified angle  
**Brief**: rotation matrix of axis (`0`, `ey`)  
**Details**: Anticlockwise rotation.  

| Param | Type | Description |
| --- | --- | --- |
| theta | <code>number</code> | angle of rotation |

<a name="Matrix3.rotZ"></a>

### Matrix3.rotZ(theta) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of rotation matrix for specified angle  
**Brief**: rotation matrix of axis (`0`, `ez`)  
**Details**: Anticlockwise rotation.  

| Param | Type | Description |
| --- | --- | --- |
| theta | <code>number</code> | angle of rotation |

<a name="Matrix3.makeRot"></a>

### Matrix3.makeRot() ⇒ <code>function</code>
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: <code>function</code> - function that generates rotation `Matrix3` for given angle  
**Brief**: rotation matrix with around axis  
**Details**: Anticlockwise rotation.  
<a name="Matrix3.makeAffine"></a>

### Matrix3.makeAffine(m, v) ⇒ <code>function</code>
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: <code>function</code> - function that computes affine transform for given `Vector3`  
**Brief**: affine transformation of the vector  

| Param | Type | Description |
| --- | --- | --- |
| m | [<code>Matrix3</code>](#Matrix3) | matrix of the transformation |
| v | <code>Vector3</code> | vector of the transformation |

<a name="Matrix3.tens"></a>

### Matrix3.tens(u, v) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - value of the tensor product  
**Brief**: tensor product of two vectors  
**Details**: Tensor product is the matrix obtained from two vectors such that `m.i.j = u.i * v.j`.  

| Param | Type | Description |
| --- | --- | --- |
| u | <code>Vector3</code> | first vector to transform |
| v | <code>Vector3</code> | second vector to transform |

<a name="Matrix3.fromArray"></a>

### Matrix3.fromArray(arr) ⇒ [<code>Matrix3</code>](#Matrix3)
**Kind**: static method of [<code>Matrix3</code>](#Matrix3)  
**Returns**: [<code>Matrix3</code>](#Matrix3) - new instance of matrix  
**Brief**: creates a matrix with given array  
**Details**: The order of the rows in matrix is the same as in `arr` array  

| Param | Type | Description |
| --- | --- | --- |
| arr | <code>Array</code> | bi-dimensional array containing rows of the matrix |

