<a name="PointPair"></a>

## PointPair
**Kind**: global class  
**Brief**: couple of points  
**Details**: `PointPair` class represents a pair of point, the _observer_ and the _mobile_.

Construct a point pair by giving position of the observer and the mobile as `Vector3`.

#### Features

- Perform **geometrical transformation** on the segment joining the two points.

- Manipulate **relative coordinates** of the mobile.  
**Author**: samiBendou  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| vector | <code>Vector3</code> | absolute coordinates of the mobile |
| origin | <code>Vector3</code> | absolute coordinates the observer |
| relative | <code>Vector3</code> | relative coordinates of the mobile |
| length | <code>number</code> | length distance between the mobile and the observer |


* [PointPair](#PointPair)
    * _instance_
        * [.translate(vector)](#PointPair+translate) ⇒ [<code>PointPair</code>](#PointPair)
        * [.homothetic(scalar)](#PointPair+homothetic) ⇒ [<code>PointPair</code>](#PointPair)
        * [.transform(matrix)](#PointPair+transform) ⇒ [<code>PointPair</code>](#PointPair)
        * [.affine(matrix, vector)](#PointPair+affine) ⇒ [<code>PointPair</code>](#PointPair)
        * [.isEqual(om)](#PointPair+isEqual) ⇒ <code>boolean</code>
    * _static_
        * [.zeros(u)](#PointPair.zeros) ⇒ [<code>PointPair</code>](#PointPair)
        * [.vect(u)](#PointPair.vect) ⇒ [<code>PointPair</code>](#PointPair)

<a name="PointPair+translate"></a>

### pointPair.translate(vector) ⇒ [<code>PointPair</code>](#PointPair)
**Kind**: instance method of [<code>PointPair</code>](#PointPair)  
**Returns**: [<code>PointPair</code>](#PointPair) - reference to this  
**Brief**: translation a point pair  

| Param | Type | Description |
| --- | --- | --- |
| vector | <code>Vector3</code> | translation vector |

<a name="PointPair+homothetic"></a>

### pointPair.homothetic(scalar) ⇒ [<code>PointPair</code>](#PointPair)
**Kind**: instance method of [<code>PointPair</code>](#PointPair)  
**Returns**: [<code>PointPair</code>](#PointPair) - reference to this  
**Brief**: homothetic transformation of a point pair  
**Details**: Scalar multiplication of the of the two points by the ratio.  

| Param | Type | Description |
| --- | --- | --- |
| scalar | <code>number</code> | ratio of transformation |

<a name="PointPair+transform"></a>

### pointPair.transform(matrix) ⇒ [<code>PointPair</code>](#PointPair)
**Kind**: instance method of [<code>PointPair</code>](#PointPair)  
**Returns**: [<code>PointPair</code>](#PointPair) - reference to this  
**Brief**: matrix transformation of the point pair  

| Param | Type | Description |
| --- | --- | --- |
| matrix | <code>Matrix3</code> | transformation matrix |

<a name="PointPair+affine"></a>

### pointPair.affine(matrix, vector) ⇒ [<code>PointPair</code>](#PointPair)
**Kind**: instance method of [<code>PointPair</code>](#PointPair)  
**Returns**: [<code>PointPair</code>](#PointPair) - reference to this  
**Brief**: affine transformation of the point pair  

| Param | Type | Description |
| --- | --- | --- |
| matrix | <code>Matrix3</code> | transformation matrix |
| vector | <code>Vector3</code> | translation vector |

<a name="PointPair+isEqual"></a>

### pointPair.isEqual(om) ⇒ <code>boolean</code>
**Kind**: instance method of [<code>PointPair</code>](#PointPair)  
**Returns**: <code>boolean</code> - `true` if the point pairs are equal  
**Brief**: equality between two point pairs  
**Details**: Verifies if relatives position of mobile are equal.  

| Param | Type | Description |
| --- | --- | --- |
| om | [<code>PointPair</code>](#PointPair) | other point pair |

<a name="PointPair.zeros"></a>

### PointPair.zeros(u) ⇒ [<code>PointPair</code>](#PointPair)
**Kind**: static method of [<code>PointPair</code>](#PointPair)  
**Returns**: [<code>PointPair</code>](#PointPair) - new instance of point pair  
**Brief**: point pair of length `0`  
**Details**: The observer can be located everywhere.  

| Param | Type | Description |
| --- | --- | --- |
| u | <code>Vector3</code> | absolution position of both the observer and mobile |

<a name="PointPair.vect"></a>

### PointPair.vect(u) ⇒ [<code>PointPair</code>](#PointPair)
**Kind**: static method of [<code>PointPair</code>](#PointPair)  
**Returns**: [<code>PointPair</code>](#PointPair) - new instance of point pair  
**Brief**: point pair by providing mobile's position only  
**Details**: Observer's position is set to zero.  

| Param | Type | Description |
| --- | --- | --- |
| u | <code>Vector3</code> | absolute position of the mobile |

