<a name="Solver"></a>

## Solver
**Kind**: global class  
**Brief**: second order differential equations solver  
**Details**: `Solver` class allows to solve equations with the form  **d2u/dt2 = f(u, t)**.

We introduce the following definition :
- **u** is the _unknown vector_ function
- **v = du/dt** is the _derivative_ of **u**
- **d2u/dt2** denotes the _second order derivative_ of **u**
- **f(u, t)** is a _smooth function_ depending only on coordinates of **u** and time **t**

Only explicit Euler's method is available for the moment.

Construct a solver by giving a solving step **dt** as `number `and a function **f** as `function`.

#### Features

- **Step by step solving**. Get the next value of **u** giving the current and previous values of u

- **Global solving**. Give the number of steps, **u0** and **v0** and get an array of samples solutions  
**Author**: samiBendou  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| **f** | <code>function</code> | function as Javascript function that takes as parameter a `Vector3` and returns a `Vector3`. |
| dt | <code>number</code> | constant step between solution samples |


* [Solver](#Solver)
    * [.step(cur, prev, t)](#Solver+step) ⇒ <code>Vector3</code>
    * [.initialTransform(u0, v0)](#Solver+initialTransform) ⇒ <code>Vector3</code>
    * [.solve(u0, v0, count)](#Solver+solve) ⇒ <code>Array</code>
    * [.trajectory(u0, v0, count, origin)](#Solver+trajectory) ⇒ <code>Trajectory</code>

<a name="Solver+step"></a>

### solver.step(cur, prev, t) ⇒ <code>Vector3</code>
**Kind**: instance method of [<code>Solver</code>](#Solver)  
**Returns**: <code>Vector3</code> - value of next solution from ODE  
**Brief**: compute one solution step  

| Param | Type | Description |
| --- | --- | --- |
| cur | <code>Vector3</code> | current value of unknown vector |
| prev | <code>Vector3</code> | previous value of unknown vector |
| t | <code>number</code> | duration since initial instant |

<a name="Solver+initialTransform"></a>

### solver.initialTransform(u0, v0) ⇒ <code>Vector3</code>
**Kind**: instance method of [<code>Solver</code>](#Solver)  
**Returns**: <code>Vector3</code> - solution right after initial instant  
**Brief**: transform speed and position initial conditions  
**Details**: Transforms the **u0**, **v0** initial condition into a **u0**, **u1** initial condition.  

| Param | Type | Description |
| --- | --- | --- |
| u0 | <code>Vector3</code> | initial unknown |
| v0 | <code>Vector3</code> | initial derivative of unknown |

<a name="Solver+solve"></a>

### solver.solve(u0, v0, count) ⇒ <code>Array</code>
**Kind**: instance method of [<code>Solver</code>](#Solver)  
**Returns**: <code>Array</code> - array containing successive solutions of ODE as `Vector3`  
**Brief**: solve ODE with `Vector3`  

| Param | Type | Description |
| --- | --- | --- |
| u0 | <code>Vector3</code> | initial unknown |
| v0 | <code>Vector3</code> | initial derivative of unknown |
| count | <code>number</code> | number of steps to solve |

<a name="Solver+trajectory"></a>

### solver.trajectory(u0, v0, count, origin) ⇒ <code>Trajectory</code>
**Kind**: instance method of [<code>Solver</code>](#Solver)  
**Returns**: <code>Trajectory</code> - new instance of trajectory containing the solution  
**Brief**: solve ODE with `PointPair`  
**Details**: The observer is considered as immobile.  

| Param | Type | Description |
| --- | --- | --- |
| u0 | <code>Vector3</code> | initial position of mobile |
| v0 | <code>Vector3</code> | initial speed of mobile |
| count | <code>number</code> | number of steps to solve |
| origin | <code>Vector3</code> | observer's position |

