<a name="Vector3"></a>

## Vector3
**Kind**: global class  
**Brief**: vectors in 3D space  
**Details**: `Vector3` class represents vectors in 3D space.

Construct a `Vector3` **cartesian coordinates** `x`, `y`, `z`.

#### Features

- Perform **vector space operations** between vectors such as addition or scalar multiplication.

- Compute the angle between two vector, the cross product and many other **geometrical operations**.

- Use cylindrical `r`, `theta`, `z` and spherical `rxy`, `theta`, `phi` coordinates
with provided **setters and getters**.  
**Author**: samiBendou  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| x | <code>number</code> | x cartesian coordinate |
| y | <code>number</code> | y cartesian coordinate |
| z | <code>number</code> | z cartesian coordinate |
| r | <code>number</code> | r spherical coordinate |
| rxy | <code>number</code> | r cylindrical coordinate |
| theta | <code>number</code> | angle formed with `ex` in radians |
| phi | <code>number</code> | angle formed with  `ez` in radians |


* [Vector3](#Vector3)
    * _instance_
        * [.opp](#Vector3+opp) ⇒ [<code>Vector3</code>](#Vector3)
        * [.setRThetaPhi()](#Vector3+setRThetaPhi)
        * [.fill(s)](#Vector3+fill)
        * [.add(u)](#Vector3+add) ⇒ [<code>Vector3</code>](#Vector3)
        * [.sub(u)](#Vector3+sub) ⇒ [<code>Vector3</code>](#Vector3)
        * [.mul(s)](#Vector3+mul) ⇒ [<code>Vector3</code>](#Vector3)
        * [.div(s)](#Vector3+div) ⇒ [<code>Vector3</code>](#Vector3)
        * [.scal(u)](#Vector3+scal) ⇒ <code>number</code>
        * [.cross(u)](#Vector3+cross) ⇒ [<code>Vector3</code>](#Vector3)
        * [.dist(u)](#Vector3+dist) ⇒ <code>number</code>
        * [.angle(u)](#Vector3+angle) ⇒ <code>number</code>
        * [.cos(u)](#Vector3+cos) ⇒ <code>number</code>
        * [.sin(u)](#Vector3+sin) ⇒ <code>number</code>
        * [.tan(u)](#Vector3+tan) ⇒ <code>number</code>
        * [.copy()](#Vector3+copy) ⇒ [<code>Vector3</code>](#Vector3)
        * [.isEqual(u)](#Vector3+isEqual) ⇒ <code>boolean</code>
        * [.isZero()](#Vector3+isZero) ⇒ <code>boolean</code>
        * [.toArray()](#Vector3+toArray) ⇒ <code>Array</code>
    * _static_
        * [.zeros](#Vector3.zeros) ⇒ [<code>Vector3</code>](#Vector3)
        * [.ones](#Vector3.ones) ⇒ [<code>Vector3</code>](#Vector3)
        * [.ex](#Vector3.ex) ⇒ [<code>Vector3</code>](#Vector3)
        * [.ey](#Vector3.ey) ⇒ [<code>Vector3</code>](#Vector3)
        * [.ez](#Vector3.ez) ⇒ [<code>Vector3</code>](#Vector3)
        * [.scal(s)](#Vector3.scal) ⇒ [<code>Vector3</code>](#Vector3)
        * [.e(k)](#Vector3.e) ⇒ [<code>Vector3</code>](#Vector3)
        * [.sum(vectors)](#Vector3.sum) ⇒ [<code>Vector3</code>](#Vector3)
        * [.comb(scalars, vectors)](#Vector3.comb) ⇒ [<code>Vector3</code>](#Vector3)
        * [.der(vectors, steps)](#Vector3.der) ⇒ <code>Array</code>
        * [.fromArray(arr)](#Vector3.fromArray) ⇒ [<code>Vector3</code>](#Vector3)

<a name="Vector3+opp"></a>

### vector3.opp ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: instance property of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - reference to this  
**Brief**: opposite of the vector  
<a name="Vector3+setRThetaPhi"></a>

### vector3.setRThetaPhi()
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Brief**: sets spherical coordinates  
**Details**: Transforms spherical coordinates to cartesian coordinates.  
<a name="Vector3+fill"></a>

### vector3.fill(s)
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Brief**: fills the vector with a single value  

| Param | Type | Description |
| --- | --- | --- |
| s | <code>number</code> | value used to fill |

<a name="Vector3+add"></a>

### vector3.add(u) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - reference to this  
**Brief**: addition between two vectors  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | vector to add |

<a name="Vector3+sub"></a>

### vector3.sub(u) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - reference to this  
**Brief**: subtraction between two vectors  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | vector to subtract |

<a name="Vector3+mul"></a>

### vector3.mul(s) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - reference to this  
**Brief**: scalar multiplication of the vector  

| Param | Type | Description |
| --- | --- | --- |
| s | <code>number</code> | scalar to multiply |

<a name="Vector3+div"></a>

### vector3.div(s) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - reference to this  
**Brief**: scalar division of the vector  

| Param | Type | Description |
| --- | --- | --- |
| s | <code>number</code> | scalar to divide |

<a name="Vector3+scal"></a>

### vector3.scal(u) ⇒ <code>number</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>number</code> - value of scalar multiplication  
**Brief**: scalar product of two vector  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | vector to multiply |

<a name="Vector3+cross"></a>

### vector3.cross(u) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - value of cross product  
**Brief**: cross product of two vector  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | vector to multiply |

<a name="Vector3+dist"></a>

### vector3.dist(u) ⇒ <code>number</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>number</code> - value of the distance  
**Brief**: distance between two vector  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | other vector |

<a name="Vector3+angle"></a>

### vector3.angle(u) ⇒ <code>number</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>number</code> - value of the angle in radians  
**Brief**: angle between two vector  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | other vector |

<a name="Vector3+cos"></a>

### vector3.cos(u) ⇒ <code>number</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>number</code> - value of the cosine  
**Brief**: cosine of the angle between two vector  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | other vector |

<a name="Vector3+sin"></a>

### vector3.sin(u) ⇒ <code>number</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>number</code> - value of the sine  
**Brief**: sine of the angle between two vector  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | other vector |

<a name="Vector3+tan"></a>

### vector3.tan(u) ⇒ <code>number</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>number</code> - value of the tangent  
**Brief**: tangent of the angle between two vector  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | other vector |

<a name="Vector3+copy"></a>

### vector3.copy() ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - new instance of cloned vector  
**Brief**: clone a vector  
<a name="Vector3+isEqual"></a>

### vector3.isEqual(u) ⇒ <code>boolean</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>boolean</code> - `true` if vectors are equal  
**Brief**: equality between two vectors  
**Details**: distance based equality  

| Param | Type | Description |
| --- | --- | --- |
| u | [<code>Vector3</code>](#Vector3) | other vector |

<a name="Vector3+isZero"></a>

### vector3.isZero() ⇒ <code>boolean</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>boolean</code> - `true` if vector is filled with zeros  
<a name="Vector3+toArray"></a>

### vector3.toArray() ⇒ <code>Array</code>
**Kind**: instance method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>Array</code> - value of the vector  
**Brief**: transform vector to array  
**Details**: The transformation is performed such that `x` is at index 0, `y` at 1 and `z` at 2  
<a name="Vector3.zeros"></a>

### Vector3.zeros ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static property of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - vector filled with `0`  
<a name="Vector3.ones"></a>

### Vector3.ones ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static property of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - vector filled with `1`  
<a name="Vector3.ex"></a>

### Vector3.ex ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static property of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - `ex = {x = 1, y = 0, z = 0}`  
<a name="Vector3.ey"></a>

### Vector3.ey ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static property of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - `ey = {x = 0, y = 1, z = 0}`  
<a name="Vector3.ez"></a>

### Vector3.ez ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static property of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - `ez = {x = 0, y = 0, z = 1}`  
<a name="Vector3.scal"></a>

### Vector3.scal(s) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - vector filled with `s`  
**Brief**: scalar vector  

| Param | Type | Description |
| --- | --- | --- |
| s | <code>number</code> | scalar value |

<a name="Vector3.e"></a>

### Vector3.e(k) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - value of the canonical vector  
**Brief**: canonical basis  
**Details**: The basis is ordered as `e(0) == ex`, `e(1) == ey`, `e(2) == ez`.  

| Param | Type | Description |
| --- | --- | --- |
| k | <code>number</code> | order of the vector in basis |

<a name="Vector3.sum"></a>

### Vector3.sum(vectors) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - value of the sum  
**Brief**: sums vectors in array  

| Param | Type | Description |
| --- | --- | --- |
| vectors | <code>Array</code> | array of `Vector3` |

<a name="Vector3.comb"></a>

### Vector3.comb(scalars, vectors) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - value of linear combination  
**Brief**: linear combination of vectors in array  

| Param | Type | Description |
| --- | --- | --- |
| scalars | <code>Array</code> | array of numbers |
| vectors | <code>Array</code> | array of `Vector3` |

<a name="Vector3.der"></a>

### Vector3.der(vectors, steps) ⇒ <code>Array</code>
**Kind**: static method of [<code>Vector3</code>](#Vector3)  
**Returns**: <code>Array</code> - array of `Vector` representing the value of the derivative  
**Brief**: derivative of an array of vector with given steps  
**Details**: Representing discrete derivative of the array of Vector3.
If the original array is of size `N`, than the derivative is of size `N - 1`.

The derivative is approximated according using the given steps between
each value and using lower bound approximation.  

| Param | Type | Description |
| --- | --- | --- |
| vectors | <code>Array</code> | array of `Vector3` to process |
| steps | <code>Array</code> | array of numbers representing steps between Vector3 |

<a name="Vector3.fromArray"></a>

### Vector3.fromArray(arr) ⇒ [<code>Vector3</code>](#Vector3)
**Kind**: static method of [<code>Vector3</code>](#Vector3)  
**Returns**: [<code>Vector3</code>](#Vector3) - new instance of vector  
**Brief**: create a vector with given array  
**Details**: The transformation is performed such that `x` is at index 0, `y` at 1 and `z` at 2.  

| Param | Type | Description |
| --- | --- | --- |
| arr | <code>Array</code> | array containing cartesian coordinates |

